@@ -1,27 +1,27 @@
 // Copyright (C) 2004-2005 Open Source Telecom Corporation.
-//  
+//
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -53,7 +53,7 @@ static unsigned getIndex(const char *id)
 
 	return idx % KEYDATA_INDEX_SIZE;
 }
-		
+
 Assoc::Assoc()
 {
 	clear();
@@ -83,8 +83,7 @@ void *Assoc::getPointer(const char *id) const
 {
 	entry *e = entries[getIndex(id)];
 
-	while(e)
-	{
+	while(e) {
 		if(!stricmp(e->id, id))
 			break;
 		e = e->next;
@@ -96,8 +95,8 @@ void *Assoc::getPointer(const char *id) const
 
 #ifdef	CCXX_NAMESPACES
 }
-#endif		
-	
+#endif
+
 /** EMACS **
  * Local variables:
  * mode: c++
