@@ -235,7 +235,7 @@ RandomFile::Error RandomFile::error(Error id, char *str)
 #ifdef	COMMON_STD_EXCEPTION
 		else if(Thread::getException() == Thread::throwException) {
 			if(!str)
-				str = "";
+				str = (char *)"";
 			throw FileException(str);
 		}
 #endif
