@@ -85,20 +85,26 @@ void LinkedDouble::leaveLock() {};
 
 LinkedDouble *LinkedDouble::getFirst(void)
 {
-	LinkedDouble *node = this;
+	LinkedDouble *node;
 
+  enterLock();
+  node = this;
 	while(node->prevObject)
 		node = node->prevObject;
+  leaveLock();
 
 	return node;
 }
 
 LinkedDouble *LinkedDouble::getLast(void)
 {
-	LinkedDouble *node = this;
+	LinkedDouble *node;
 
+  enterLock();
+  node = this;
 	while(node->nextObject)
 		node = node->nextObject;
+  leaveLock();
 
 	return node;
 }
@@ -123,6 +129,53 @@ void LinkedDouble::insert(LinkedDouble &obj)
 	leaveLock();
 }
 
+void LinkedDouble::insert(InsertMode position, LinkedDouble& obj)
+{
+  LinkedDouble *node;
+
+  enterLock();
+  obj.detach();
+
+  switch ( position )
+  {
+    case modeAtFirst :
+      node = getFirst();
+      obj.nextObject = node;
+      node->prevObject = &obj;
+      break;
+
+    case modeBefore :
+      obj.nextObject = this;
+      obj.prevObject = this->prevObject;
+      this->prevObject = &obj;
+      if (obj.prevObject)
+        obj.prevObject->nextObject = &obj;
+      break;
+
+    case modeAfter :
+      obj.nextObject = this->nextObject;
+      obj.prevObject = this;
+      this->nextObject = &obj;
+      if (obj.nextObject)
+        obj.nextObject->prevObject = &obj;
+      break;
+
+    case modeAtLast :
+      node = getLast();
+      obj.nextObject = node->nextObject;
+      obj.prevObject = node;
+      node->nextObject = &obj;
+      if(obj.nextObject)
+        obj.nextObject->prevObject = &obj;
+      break;
+
+    default :
+      insert(obj);
+      break;
+  }
+  leaveLock();
+}
+
 void LinkedDouble::detach(void)
 {
 	enterLock();
@@ -133,9 +186,24 @@ void LinkedDouble::detach(void)
 	if(nextObject)
 		nextObject->prevObject = prevObject;
 
+	prevObject = NULL;
+	nextObject = NULL;
+
 	leaveLock();
 }
 
+LinkedDouble &LinkedDouble::operator+=(LinkedDouble &obj)
+{
+  insert(obj);
+  return *this;
+}
+
+LinkedDouble &LinkedDouble::operator--()
+{
+  detach();
+  return *this;
+}
+
 #ifdef	CCXX_NAMESPACES
 }
 #endif
