@@ -1,27 +1,27 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
-//  
+//
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -82,23 +82,23 @@ static inline unsigned long F(unsigned long x, unsigned long y, unsigned long z)
 {
 	return (x & y) | (~x & z);
 }
- 
+
 static inline unsigned long G(unsigned long x, unsigned long y, unsigned long z)
 {
 	return (x & z) | (y & ~z);
 }
- 
+
 static inline unsigned long H(unsigned long x, unsigned long y, unsigned long z)
 {
 	return x ^ y ^ z;
 }
- 
+
 inline unsigned long I(unsigned long x, unsigned long y, unsigned long z)
 {
 	return y ^ (x | ~z);
 }
 
-   
+
 static void FF(unsigned long &a, unsigned long b, unsigned long c, unsigned long d, unsigned long x, unsigned long s, unsigned long ac)
 {
 	a += F(b, c, d) + x + ac;
@@ -230,7 +230,7 @@ void MD5Digest::update(void)
 	HH(a, b, c, d, x[ 9], S31, 0xd9d4d039);
 	HH(d, a, b, c, x[12], S32, 0xe6db99e5);
 	HH(c, d, a, b, x[15], S33, 0x1fa27cf8);
-	HH(b, c, d, a, x[ 2], S34, 0xc4ac5665); 
+	HH(b, c, d, a, x[ 2], S34, 0xc4ac5665);
 
 	II(a, b, c, d, x[ 0], S41, 0xf4292244);
 	II(d, a, b, c, x[ 7], S42, 0x432aff97);
@@ -262,9 +262,9 @@ void MD5Digest::commit(void)
 	unsigned long i, len;
 
  	static unsigned char pad[64]={
-    		0x80, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-    		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-    		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
+			0x80, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+			0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+			0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
 
 	bpos = (unsigned)((unsigned char*)pptr() - buf);
 	if(!updated && !bpos)
@@ -274,8 +274,7 @@ void MD5Digest::commit(void)
 	if(count[0] < (unsigned long)(bpos << 3))
 		++count[1];
 
-	for(i = 0; i < 2; ++i)
-	{
+	for(i = 0; i < 2; ++i) {
 		cbuf[i * 4] = (unsigned char)count[i] & 0xff;
 		cbuf[i * 4 + 1] = (unsigned char)((count[i] >> 8) & 0xff);
 		cbuf[i * 4 + 2] = (unsigned char)((count[i] >> 16) & 0xff);
@@ -289,12 +288,11 @@ void MD5Digest::commit(void)
 
 	putDigest(cbuf, 8);
 
-	for(i = 0; i < 4; ++i)
-	{
+	for(i = 0; i < 4; ++i) {
 		md5[i * 4] = (unsigned char)state[i] & 0xff;
-                md5[i * 4 + 1] = (unsigned char)((state[i] >> 8) & 0xff);
-                md5[i * 4 + 2] = (unsigned char)((state[i] >> 16) & 0xff);
-                md5[i * 4 + 3] = (unsigned char)((state[i] >> 24) & 0xff);
+		md5[i * 4 + 1] = (unsigned char)((state[i] >> 8) & 0xff);
+		md5[i * 4 + 2] = (unsigned char)((state[i] >> 16) & 0xff);
+		md5[i * 4 + 3] = (unsigned char)((state[i] >> 24) & 0xff);
 	}
 	initDigest();
 }
@@ -312,8 +310,7 @@ void MD5Digest::putDigest(const unsigned char *buffer, unsigned len)
 	bpos = (unsigned)((unsigned char*)pptr()-buf);
 	if(bpos >= 64)
 		update();
-	while(len--)
-	{
+	while(len--) {
 		buf[bpos++] = *(buffer++);
 		if(bpos >= 64)
 			update();
@@ -336,5 +333,5 @@ ostream &MD5Digest::strDigest(ostream &os)
 
 #ifdef	CCXX_NAMESPACES
 }
-#endif	
-	
+#endif
+
