@@ -1,27 +1,27 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
-//  
+//
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -69,8 +69,7 @@ MemPager::MemPager(size_t pg)
 #endif
 #if defined(HAVE_POSIX_MEMALIGN)
 	unsigned p2 = 2;
-	if(!malign)
-	{
+	if(!malign) {
 		while(p2 < sizeof(void *))
 			p2 *= 2;
 		while(((p2 / sizeof(void *)) * sizeof(void *)) != p2)
@@ -81,8 +80,8 @@ MemPager::MemPager(size_t pg)
 #else
 	page = (struct _page *)::new void *[pagesize / sizeof(void *)];
 #endif
-        page->next = NULL;
-        page->used = sizeof(struct _page);
+	page->next = NULL;
+	page->used = sizeof(struct _page);
 }
 
 MemPager::~MemPager()
@@ -94,8 +93,7 @@ void MemPager::clean(void)
 {
 	struct _page *root = page;
 
-	while(root)
-	{
+	while(root) {
 		page = page->next;
 #ifdef	COMMON_MEMORY_AUDIT
 		slog(Slog::levelDebug) << "MemPager: delete, id="
@@ -117,8 +115,7 @@ void MemPager::purge(void)
 {
 	struct _page *root = page;
 
-	while(root->next)
-	{
+	while(root->next) {
 		page = root->next;
 #ifdef	COMMON_MEMORY_AUDIT
 		slog(Slog::levelDebug) << "Mempager: delete, id="
@@ -134,7 +131,7 @@ void MemPager::purge(void)
 	}
 	page->used = sizeof(struct _page);
 }
-	
+
 
 void *MemPager::alloc(size_t size)
 {
@@ -143,12 +140,11 @@ void *MemPager::alloc(size_t size)
 
 #if __BYTE_ALIGNMENT > 1
 	size_t align = size % palign;
-	if (align) 
+	if (align)
 		size += palign - align;
 #endif
 
-	if(size > pagesize - sizeof(struct _page))
-	{
+	if(size > pagesize - sizeof(struct _page)) {
 		slog.critical("mempager overflow");
 #ifdef	CCXX_EXCEPTIONS
 		if(Thread::getException() == Thread::throwObject)
@@ -162,8 +158,7 @@ void *MemPager::alloc(size_t size)
 #endif
 	}
 
-	if(page->used + size > pagesize)
-	{
+	if(page->used + size > pagesize) {
 #if defined(HAVE_POSIX_MEMALIGN)
 		posix_memalign((void **)&npage, malign, pagesize);
 #else
@@ -182,7 +177,7 @@ void *MemPager::alloc(size_t size)
 	ptr = (char *)page;
 	ptr += page->used;
 	page->used += size;
-	return (void *)ptr; 
+	return (void *)ptr;
 }
 
 void *MemPager::first(size_t size)
@@ -192,13 +187,12 @@ void *MemPager::first(size_t size)
 
 #if	__BYTE_ALIGNMENT > 1
 	size_t align = size % palign;
-		
-	if (align) 
+
+	if (align)
 		size += palign - align;
 #endif
 
-	while(npage)
-	{
+	while(npage) {
 		if(npage->used + size <= pagesize)
 			break;
 
@@ -243,14 +237,13 @@ void *StackPager::pull(void)
 {
 	frame_t *object = stack;
 
-	if(!stack)
-	{
+	if(!stack) {
 		purge();
 		return NULL;
 	}
 
 	stack = object->next;
-	return object->data;	
+	return object->data;
 }
 
 void *StackPager::push(const void* object, size_t len)
@@ -259,7 +252,7 @@ void *StackPager::push(const void* object, size_t len)
 
 	if(!frame)
 		return NULL;
-	
+
 	frame->next = stack;
 	stack = frame;
 	memcpy(frame->data, object, len);
