@@ -141,7 +141,7 @@ namespace ost {
 
 #ifdef CCXX_NAT
 
-char * natmsg[] = {
+const char * natmsg[] = {
 		"nat lookup successful",
 		"nat address not in table",
 		"nat not supported/implemented",
@@ -363,7 +363,7 @@ natResult natv6Lookup( SOCKET sfd, struct sockaddr_in6 * nat ) {
 #endif
 
 char * natErrorString( natResult res ) {
-	return natmsg[ ( res >= natOK && res <= natIFaceErr ) ? res : natUnkownErr ];
+	return (char *)natmsg[ ( res >= natOK && res <= natIFaceErr ) ? res : natUnkownErr ];
 }
 
 #else
