@@ -4,7 +4,7 @@
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -13,15 +13,15 @@
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -55,7 +55,7 @@
 namespace ost {
 #endif
 
-UDPTransmit::UDPTransmit(const IPV4Address &ia, tpport_t port) : 
+UDPTransmit::UDPTransmit(const IPV4Address &ia, tpport_t port) :
 UDPSocket(ia, port)
 {
 	disconnect();	// assure not started live
@@ -64,11 +64,11 @@ UDPSocket(ia, port)
 }
 
 #ifdef	CCXX_IPV6
-UDPTransmit::UDPTransmit(const IPV6Address &ia, tpport_t port) :   
+UDPTransmit::UDPTransmit(const IPV6Address &ia, tpport_t port) :
 UDPSocket(ia, port)
 {
-        disconnect();   // assure not started live
-        shutdown(so, 0);
+	disconnect();   // assure not started live
+	shutdown(so, 0);
 	receiveBuffer(0);
 }
 #endif
@@ -100,18 +100,18 @@ Socket::Error UDPTransmit::cConnect(const IPV4Address &ia, tpport_t port)
 
 Socket::Error UDPTransmit::connect(const IPV6Address &ia, tpport_t port)
 {
-        int len = sizeof(peer.ipv6);
+	int len = sizeof(peer.ipv6);
 
-        peer.ipv6.sin6_family = AF_INET6;
-        peer.ipv6.sin6_addr = getaddress(ia);
-        peer.ipv6.sin6_port = htons(port);
-        // Win32 will crash if you try to connect to INADDR_ANY.
+	peer.ipv6.sin6_family = AF_INET6;
+	peer.ipv6.sin6_addr = getaddress(ia);
+	peer.ipv6.sin6_port = htons(port);
+	// Win32 will crash if you try to connect to INADDR_ANY.
 	if(!memcmp(&peer.ipv6.sin6_addr, &in6addr_any, sizeof(in6addr_any)))
-		memcpy(&peer.ipv6.sin6_addr, &in6addr_loopback, 
+		memcpy(&peer.ipv6.sin6_addr, &in6addr_loopback,
 			sizeof(in6addr_loopback));
-        if(::connect(so, (struct sockaddr *)&peer.ipv6, len))
-                return connectError();
-        return errSuccess;
+	if(::connect(so, (struct sockaddr *)&peer.ipv6, len))
+		return connectError();
+	return errSuccess;
 }
 #endif
 
@@ -143,15 +143,15 @@ Socket::Error UDPTransmit::connect(const IPV4Multicast &group, tpport_t port)
 #ifdef	CCXX_IPV6
 Socket::Error UDPTransmit::connect(const IPV6Multicast &group, tpport_t port)
 {
-        Error error;
-        if(!( error = UDPSocket::setMulticast(true) ))
-                return error;
+	Error error;
+	if(!( error = UDPSocket::setMulticast(true) ))
+		return error;
 
-        return connect((IPV6Address)group,port);
+	return connect((IPV6Address)group,port);
 }
 #endif
 
-UDPReceive::UDPReceive(const IPV4Address &ia, tpport_t port) : 
+UDPReceive::UDPReceive(const IPV4Address &ia, tpport_t port) :
 UDPSocket(ia, port)
 {
 	shutdown(so, 1);
@@ -162,7 +162,7 @@ UDPSocket(ia, port)
 UDPReceive::UDPReceive(const IPV6Address &ia, tpport_t port) :
 UDPSocket(ia, port)
 {
-        shutdown(so, 1);
+	shutdown(so, 1);
 	sendBuffer(0);
 }
 #endif
@@ -185,17 +185,17 @@ Socket::Error UDPReceive::connect(const IPV4Host &ia, tpport_t port)
 #ifdef	CCXX_IPV6
 Socket::Error UDPReceive::connect(const IPV6Host &ia, tpport_t port)
 {
-        int len = sizeof(peer.ipv6);
+	int len = sizeof(peer.ipv6);
 
-        peer.ipv6.sin6_family = AF_INET6;
-        peer.ipv6.sin6_addr = getaddress(ia);
-        peer.ipv6.sin6_port = htons(port);
-        // Win32 will crash if you try to connect to INADDR_ANY.
+	peer.ipv6.sin6_family = AF_INET6;
+	peer.ipv6.sin6_addr = getaddress(ia);
+	peer.ipv6.sin6_port = htons(port);
+	// Win32 will crash if you try to connect to INADDR_ANY.
 	if(!memcmp(&peer.ipv6.sin6_addr, &in6addr_any, sizeof(in6addr_any)))
 		memcpy(&peer.ipv6.sin6_addr, &in6addr_loopback, sizeof(in6addr_loopback));
-        if(::connect(so, (sockaddr *)&peer.ipv6, len))
-                return connectError();
-        return errSuccess;
+	if(::connect(so, (sockaddr *)&peer.ipv6, len))
+		return connectError();
+	return errSuccess;
 }
 #endif
 
@@ -212,8 +212,7 @@ UDPTransmit(bind, port + 1), UDPReceive(bind, port)
 Socket::Error UDPDuplex::connect(const IPV4Host &host, tpport_t port)
 {
 	Error rtn = UDPTransmit::connect(host, port);
-	if(rtn)
-	{
+	if(rtn) {
 		UDPTransmit::disconnect();
 		UDPReceive::disconnect();
 		return rtn;
@@ -224,14 +223,13 @@ Socket::Error UDPDuplex::connect(const IPV4Host &host, tpport_t port)
 #ifdef	CCXX_IPV6
 Socket::Error UDPDuplex::connect(const IPV6Host &host, tpport_t port)
 {
-        Error rtn = UDPTransmit::connect(host, port);
-        if(rtn)
-        {
-                UDPTransmit::disconnect();
-                UDPReceive::disconnect();
-                return rtn;
-        }
-        return UDPReceive::connect(host, port + 1);
+	Error rtn = UDPTransmit::connect(host, port);
+	if(rtn) {
+		UDPTransmit::disconnect();
+		UDPReceive::disconnect();
+		return rtn;
+	}
+	return UDPReceive::connect(host, port + 1);
 }
 #endif
 
