@@ -1,3 +1,5 @@
+#ifndef	CCXX_PRIVATE_H_
+#define	CCXX_PRIVATE_H_
 
 #ifdef CCXX_NAMESPACES
 namespace ost {
@@ -51,7 +53,7 @@ friend class Slog;
 	// log information
 	size_t _msgpos;
 	char _msgbuf[128];
-	enum Thread::Throw _throw;
+	Thread::Throw _throw;
 	cctid_t _tid;
 
 #ifndef WIN32
@@ -83,3 +85,4 @@ public:
 }
 #endif
 
+#endif
