@@ -319,7 +319,7 @@ Serial::Error Serial::error(Error err, char *errs)
 #ifdef	COMMON_STD_EXCEPTION
 	else if(Thread::getException() == Thread::throwException) {
 		if(!errs)
-			errs = "";
+			errs = (char *)"";
 		throw SerException(String(errs));
 	}
 #endif
