@@ -159,7 +159,7 @@ Socket::Socket(int domain, int type, int protocol)
 	setSocket();
 	so = socket(domain, type, protocol);
 	if(so == INVALID_SOCKET) {
-		error(errCreateFailed,"Could not create socket",socket_errno);
+		error(errCreateFailed,(char *)"Could not create socket",socket_errno);
 		return;
 	}
 #ifdef	SO_NOSIGPIPE
@@ -173,7 +173,7 @@ Socket::Socket(SOCKET fd)
 {
 	setSocket();
 	if (fd == INVALID_SOCKET) {
-		error(errCreateFailed,"Invalid socket handle passed",0);
+		error(errCreateFailed,(char *)"Invalid socket handle passed",0);
 		return;
 	}
 	so = fd;
@@ -185,7 +185,7 @@ Socket::Socket(const Socket &orig)
 	setSocket();
 	so = DUP_SOCK(orig.so,orig.state);
 	if(so == INVALID_SOCKET)
-		error(errCopyFailed,"Could not duplicate socket handle",socket_errno);
+		error(errCopyFailed,(char *)"Could not duplicate socket handle",socket_errno);
 	state = orig.state;
 }
 
@@ -318,13 +318,13 @@ ssize_t Socket::readLine(char *str, size_t request, timeout_t timeout)
 	while(nleft && !nl) {
 		if(timeout) {
 			if(!isPending(pendingInput, timeout)) {
-				error(errTimeout,"Read timeout", 0);
+				error(errTimeout,(char *)"Read timeout", 0);
 				return -1;
 			}
 		}
 		nstat = ::recv(so, str, _IOLEN64 nleft, MSG_PEEK);
 		if(nstat <= 0) {
-			error(errInput,"Could not read from socket", socket_errno);
+			error(errInput,(char *)"Could not read from socket", socket_errno);
 			return -1;
 		}
 
@@ -536,7 +536,7 @@ Socket::Error Socket::connectError(void)
 #else
 Socket::Error Socket::connectError(void)
 {
-	char* str = "Could not connect to remote host";
+	char* str = (char *)"Could not connect to remote host";
 	switch(errno) {
 #ifdef	EHOSTUNREACH
 	case EHOSTUNREACH:
@@ -584,7 +584,7 @@ Socket::Error Socket::error(Error err, char *errs, long systemError) const
 	case Thread::throwException:
 		{
 			if(!errs)
-				errs = "";
+				errs = (char *)"";
 			throw SockException(String(errs), err, systemError);
 		}
 #endif
@@ -610,7 +610,7 @@ Socket::Error Socket::setBroadcast(bool enable)
 	int opt = (enable ? 1 : 0);
 	if(setsockopt(so, SOL_SOCKET, SO_BROADCAST,
 		      (char *)&opt, (socklen_t)sizeof(opt)))
-		return error(errBroadcastDenied,"Could not set socket broadcast option",socket_errno);
+		return error(errBroadcastDenied,(char *)"Could not set socket broadcast option",socket_errno);
 	flags.broadcast = enable;
 	return errSuccess;
 }
@@ -621,7 +621,7 @@ Socket::Error Socket::setKeepAlive(bool enable)
 #if (defined(SO_KEEPALIVE) || defined(WIN32))
 	if(setsockopt(so, SOL_SOCKET, SO_KEEPALIVE,
 		      (char *)&opt, (socklen_t)sizeof(opt)))
-		return error(errKeepaliveDenied,"Could not set socket keep-alive option",socket_errno);
+		return error(errKeepaliveDenied,(char *)"Could not set socket keep-alive option",socket_errno);
 #endif
 	flags.keepalive = enable;
 	return errSuccess;
@@ -633,7 +633,7 @@ Socket::Error Socket::setLinger(bool linger)
 	flags.linger = linger;
 	return errSuccess;
 #else
-	return error(errServiceUnavailable,"Socket lingering not supported");
+	return error(errServiceUnavailable,(char *)"Socket lingering not supported");
 #endif
 }
 
@@ -644,7 +644,7 @@ Socket::Error Socket::setRouting(bool enable)
 #ifdef	SO_DONTROUTE
 	if(setsockopt(so, SOL_SOCKET, SO_DONTROUTE,
 		      (char *)&opt, (socklen_t)sizeof(opt)))
-		return error(errRoutingDenied,"Could not set dont-route socket option",socket_errno);
+		return error(errRoutingDenied,(char *)"Could not set dont-route socket option",socket_errno);
 #endif
 	flags.route = enable;
 	return errSuccess;
@@ -656,7 +656,7 @@ Socket::Error Socket::setNoDelay(bool enable)
 
 	if(setsockopt(so, IPPROTO_TCP, TCP_NODELAY,
 		      (char *)&opt, (socklen_t)sizeof(opt)))
-		return error(errNoDelay,"Could not set tcp-nodelay socket option",socket_errno);
+		return error(errNoDelay,(char *)"Could not set tcp-nodelay socket option",socket_errno);
 
 
 	return errSuccess;
@@ -688,20 +688,20 @@ Socket::Error Socket::setTypeOfService(Tos service)
 		break;
 #endif
 	default:
-		return error(errServiceUnavailable,"Unknown type-of-service");
+		return error(errServiceUnavailable,(char *)"Unknown type-of-service");
 	}
 	if(setsockopt(so, SOL_IP, IP_TOS,(char *)&tos, (socklen_t)sizeof(tos)))
-		return error(errServiceDenied,"Could not set type-of-service",socket_errno);
+		return error(errServiceDenied,(char *)"Could not set type-of-service",socket_errno);
 	return errSuccess;
 #else
-	return error(errServiceUnavailable,"Socket type-of-service not supported",socket_errno);
+	return error(errServiceUnavailable,(char *)"Socket type-of-service not supported",socket_errno);
 #endif
 }
 
 Socket::Error Socket::setTimeToLiveByFamily(unsigned char ttl, Family fam)
 {
 	if(!flags.multicast)
-		return error(errMulticastDisabled,"Multicast not enabled on socket");
+		return error(errMulticastDisabled,(char *)"Multicast not enabled on socket");
 
 	switch(fam) {
 #ifdef	CCXX_IPV6
@@ -717,7 +717,7 @@ Socket::Error Socket::setTimeToLiveByFamily(unsigned char ttl, Family fam)
 		return errSuccess;
 #endif
 	default:
-		return error(errServiceUnavailable, "Multicast not supported");
+		return error(errServiceUnavailable, (char *)"Multicast not supported");
 	}
 }
 
@@ -726,7 +726,7 @@ Socket::Error Socket::setLoopbackByFamily(bool enable, Family family)
 	unsigned char loop;
 
 	if(!flags.multicast)
-		return error(errMulticastDisabled,"Multicast not enabled on socket");
+		return error(errMulticastDisabled,(char *)"Multicast not enabled on socket");
 
 	if(enable)
 		loop = 1;
@@ -746,7 +746,7 @@ Socket::Error Socket::setLoopbackByFamily(bool enable, Family family)
 		return errSuccess;
 #endif
 	default:
-		return error(errServiceUnavailable,"Multicast not supported");
+		return error(errServiceUnavailable,(char *)"Multicast not supported");
 	}
 }
 
@@ -847,7 +847,7 @@ Socket &Socket::operator=(const Socket &from)
 
 	so = DUP_SOCK(from.so,from.state);
 	if(so == INVALID_SOCKET) {
-		error(errCopyFailed,"Could not duplicate socket handle",socket_errno);
+		error(errCopyFailed,(char *)"Could not duplicate socket handle",socket_errno);
 		state = INITIAL;
 	}
 	else
@@ -905,7 +905,7 @@ IPV4Host Socket::getIPV4Sender(tpport_t *port) const
 			*port = 0;
 
 		memset((void*) &from, 0, sizeof(from));
-		error(errInput,"Could not read from socket",socket_errno);
+		error(errInput,(char *)"Could not read from socket",socket_errno);
 	}
 #else
 	if(rc < 1) {
@@ -913,7 +913,7 @@ IPV4Host Socket::getIPV4Sender(tpport_t *port) const
 			*port = 0;
 
 		memset((void*) &from, 0, sizeof(from));
-		error(errInput,"Could not read from socket",socket_errno);
+		error(errInput,(char *)"Could not read from socket",socket_errno);
 	}
 #endif
 	else {
@@ -939,7 +939,7 @@ IPV6Host Socket::getIPV6Sender(tpport_t *port) const
 			*port = 0;
 
 		memset((void*) &from, 0, sizeof(from));
-		error(errInput,"Could not read from socket",socket_errno);
+		error(errInput,(char *)"Could not read from socket",socket_errno);
 	}
 #else
 	if(rc < 1) {
@@ -947,7 +947,7 @@ IPV6Host Socket::getIPV6Sender(tpport_t *port) const
 			*port = 0;
 
 		memset((void*) &from, 0, sizeof(from));
-		error(errInput,"Could not read from socket",socket_errno);
+		error(errInput,(char *)"Could not read from socket",socket_errno);
 	}
 #endif
 	else {
@@ -965,7 +965,7 @@ IPV4Host Socket::getIPV4Local(tpport_t *port) const
 	socklen_t len = sizeof(addr);
 
 	if(getsockname(so, (struct sockaddr *)&addr, &len)) {
-		error(errResourceFailure,"Could not get socket address",socket_errno);
+		error(errResourceFailure,(char *)"Could not get socket address",socket_errno);
 	      	if(port)
 			*port = 0;
 		memset(&addr.sin_addr, 0, sizeof(addr.sin_addr));
@@ -984,7 +984,7 @@ IPV6Host Socket::getIPV6Local(tpport_t *port) const
 	socklen_t len = sizeof(addr);
 
 	if(getsockname(so, (struct sockaddr *)&addr, &len)) {
-		error(errResourceFailure,"Could not get socket address",socket_errno);
+		error(errResourceFailure,(char *)"Could not get socket address",socket_errno);
 	      	if(port)
 			*port = 0;
 		memset(&addr.sin6_addr, 0, sizeof(addr.sin6_addr));
@@ -1054,10 +1054,10 @@ IPV4Host Socket::getIPV4Peer(tpport_t *port) const
 	if(getpeername(so, (struct sockaddr *)&addr, &len)) {
 #ifndef WIN32
 		if(errno == ENOTCONN)
-			error(errNotConnected,"Could not get peer address",socket_errno);
+			error(errNotConnected,(char *)"Could not get peer address",socket_errno);
 		else
 #endif
-			error(errResourceFailure,"Could not get peer address",socket_errno);
+			error(errResourceFailure,(char *)"Could not get peer address",socket_errno);
 		if(port)
 			*port = 0;
 		memset(&addr.sin_addr, 0, sizeof(addr.sin_addr));
@@ -1078,10 +1078,10 @@ IPV6Host Socket::getIPV6Peer(tpport_t *port) const
 	if(getpeername(so, (struct sockaddr *)&addr, &len)) {
 #ifndef WIN32
 		if(errno == ENOTCONN)
-			error(errNotConnected,"Could not get peer address",socket_errno);
+			error(errNotConnected,(char *)"Could not get peer address",socket_errno);
 		else
 #endif
-			error(errResourceFailure,"Could not get peer address",socket_errno);
+			error(errResourceFailure,(char *)"Could not get peer address",socket_errno);
 		if(port)
 			*port = 0;
 		memset(&addr.sin6_addr, 0, sizeof(addr.sin6_addr));
@@ -1134,7 +1134,7 @@ Socket::Error Socket::setMulticastByFamily(bool enable, Family family)
 		return errSuccess;
 #endif
 	default:
-		return error(errServiceUnavailable,"Multicast not supported");
+		return error(errServiceUnavailable,(char *)"Multicast not supported");
 	}
 }
 
@@ -1146,7 +1146,7 @@ Socket::Error Socket::join(const IPV4Multicast &ia)
 	socklen_t len = sizeof(myaddr);
 
 	if(!flags.multicast)
-		return error(errMulticastDisabled,"Multicast not enabled on socket");
+		return error(errMulticastDisabled,(char *)"Multicast not enabled on socket");
 
 	getsockname(so, (struct sockaddr *)&myaddr, &len);
 	memcpy(&group.imr_interface, &myaddr.sin_addr, sizeof(&myaddr.sin_addr));
@@ -1154,7 +1154,7 @@ Socket::Error Socket::join(const IPV4Multicast &ia)
 	setsockopt(so, IPPROTO_IP, IP_ADD_MEMBERSHIP, (char *)&group, sizeof(group));
 	return errSuccess;
 #else
-	return error(errServiceUnavailable,"Multicast not supported");
+	return error(errServiceUnavailable,(char *)"Multicast not supported");
 #endif
 }
 
@@ -1167,7 +1167,7 @@ Socket::Error Socket::join(const IPV6Multicast &ia)
 	socklen_t len = sizeof(myaddr);
 
 	if(!flags.multicast)
-		return error(errMulticastDisabled,"Multicast not enabled on socket");
+		return error(errMulticastDisabled,(char *)"Multicast not enabled on socket");
 
 	getsockname(so, (struct sockaddr *)&myaddr, &len);
 	memcpy(&group.ipv6mr_interface, &myaddr.sin6_addr, sizeof(&myaddr.sin6_addr));
@@ -1175,7 +1175,7 @@ Socket::Error Socket::join(const IPV6Multicast &ia)
 	setsockopt(so, IPPROTO_IPV6, IPV6_ADD_MEMBERSHIP, (char *)&group, sizeof(group));
 	return errSuccess;
 #else
-	return error(errServiceUnavailable,"Multicast not supported");
+	return error(errServiceUnavailable,(char *)"Multicast not supported");
 #endif
 }
 
@@ -1189,7 +1189,7 @@ Socket::Error Socket::drop(const IPV4Multicast &ia)
 	socklen_t len = sizeof(myaddr);
 
 	if(!flags.multicast)
-		return error(errMulticastDisabled,"Multicast not enabled on socket");
+		return error(errMulticastDisabled,(char *)"Multicast not enabled on socket");
 
 	getsockname(so, (struct sockaddr *)&myaddr, &len);
 	memcpy(&group.imr_interface, &myaddr.sin_addr, sizeof(&myaddr.sin_addr));
@@ -1197,7 +1197,7 @@ Socket::Error Socket::drop(const IPV4Multicast &ia)
 	setsockopt(so, IPPROTO_IP, IP_DROP_MEMBERSHIP, (char *)&group, sizeof(group));
 	return errSuccess;
 #else
-	return error(errServiceUnavailable,"Multicast not supported");
+	return error(errServiceUnavailable,(char *)"Multicast not supported");
 #endif
 }
 
@@ -1210,7 +1210,7 @@ Socket::Error Socket::drop(const IPV6Multicast &ia)
 	socklen_t len = sizeof(myaddr);
 
 	if(!flags.multicast)
-		return error(errMulticastDisabled,"Multicast not enabled on socket");
+		return error(errMulticastDisabled,(char *)"Multicast not enabled on socket");
 
 	getsockname(so, (struct sockaddr *)&myaddr, &len);
 	memcpy(&group.ipv6mr_interface, &myaddr.sin6_addr, sizeof(&myaddr.sin6_addr));
@@ -1218,7 +1218,7 @@ Socket::Error Socket::drop(const IPV6Multicast &ia)
 	setsockopt(so, IPPROTO_IPV6, IPV6_DROP_MEMBERSHIP, (char *)&group, sizeof(group));
 	return errSuccess;
 #else
-	return error(errServiceUnavailable,"Multicast not supported");
+	return error(errServiceUnavailable,(char *)"Multicast not supported");
 #endif
 }
 #endif
@@ -1267,7 +1267,7 @@ Socket(fam, SOCK_DGRAM, IPPROTO_UDP)
 	hint.ai_flags = AI_PASSIVE;
 
 	if(getaddrinfo(name, cp, &hint, &list) || !list) {
-		error(errBindingFailed, "Could not find service", errno);
+		error(errBindingFailed, (char *)"Could not find service", errno);
 		endSocket();
 		return;
 	}
@@ -1291,7 +1291,7 @@ Socket(fam, SOCK_DGRAM, IPPROTO_UDP)
 
 	if(state != BOUND) {
 		endSocket();
-		error(errBindingFailed, "Count not bind socket", errno);
+		error(errBindingFailed, (char *)"Count not bind socket", errno);
 		return;
 	}
 }
@@ -1332,7 +1332,7 @@ Socket(fam, SOCK_DGRAM, IPPROTO_UDP)
 			port = ntohs(svc->s_port);
 		mutex.leave();
 		if(!svc) {
-			error(errBindingFailed, "Could not find service", errno);
+			error(errBindingFailed, (char *)"Could not find service", errno);
 			endSocket();
 			return;
 		}
@@ -1378,7 +1378,7 @@ Socket(fam, SOCK_DGRAM, IPPROTO_UDP)
 
 	if(state != BOUND) {
 		endSocket();
-		error(errBindingFailed, "Count not bind socket", errno);
+		error(errBindingFailed, (char *)"Count not bind socket", errno);
 		return;
 	}
 }
@@ -1415,7 +1415,7 @@ Socket(AF_INET, SOCK_DGRAM, IPPROTO_UDP)
 #endif
 	if(bind(so, (struct sockaddr *)&peer.ipv4, sizeof(peer.ipv4))) {
 		endSocket();
-		error(errBindingFailed,"Could not bind socket",socket_errno);
+		error(errBindingFailed,(char *)"Could not bind socket",socket_errno);
 		return;
 	}
 	state = BOUND;
@@ -1436,7 +1436,7 @@ Socket(AF_INET6, SOCK_DGRAM, IPPROTO_UDP)
 #endif
 	if(bind(so, (struct sockaddr *)&peer.ipv6, sizeof(peer.ipv6))) {
 		endSocket();
-		error(errBindingFailed,"Could not bind socket",socket_errno);
+		error(errBindingFailed,(char *)"Could not bind socket",socket_errno);
 		return;
 	}
 	state = BOUND;
@@ -1907,7 +1907,7 @@ Socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)
 
 	if(getaddrinfo(name, cp, &hint, &list) || !list) {
 		endSocket();
-		error(errBindingFailed, "Could not find service", errno);
+		error(errBindingFailed, (char *)"Could not find service", errno);
 		return;
 	}
 
@@ -1928,14 +1928,14 @@ Socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)
 	freeaddrinfo(first);
 	if(state != BOUND) {
 		endSocket();
-		error(errBindingFailed,"Could not bind socket",socket_errno);
+		error(errBindingFailed,(char *)"Could not bind socket",socket_errno);
 		return;
 	}
 
 	setSegmentSize(mss);
 	if(listen(so, backlog)) {
 		endSocket();
-		error(errBindingFailed,"Could not listen on socket",socket_errno);
+		error(errBindingFailed,(char *)"Could not listen on socket",socket_errno);
 		return;
 	}
 }
@@ -1991,14 +1991,14 @@ Socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)
 
 	if(bind(so, (struct sockaddr *)&addr, sizeof(addr))) {
 		endSocket();
-		error(errBindingFailed,"Could not bind socket",socket_errno);
+		error(errBindingFailed,(char *)"Could not bind socket",socket_errno);
 		return;
 	}
 
 	setSegmentSize(mss);
 	if(listen(so, backlog)) {
 		endSocket();
-		error(errBindingFailed,"Could not listen on socket",
+		error(errBindingFailed,(char *)"Could not listen on socket",
 			socket_errno);
 		return;
 	}
@@ -2023,7 +2023,7 @@ Socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)
 #endif
 	if(bind(so, (struct sockaddr *)&addr, sizeof(addr))) {
 		endSocket();
-		error(errBindingFailed,"Could not bind socket",socket_errno);
+		error(errBindingFailed,(char *)"Could not bind socket",socket_errno);
 		return;
 	}
 
@@ -2031,7 +2031,7 @@ Socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)
 
 	if(listen(so, backlog)) {
 		endSocket();
-		error(errBindingFailed,"Could not listen on socket",socket_errno);
+		error(errBindingFailed,(char *)"Could not listen on socket",socket_errno);
 		return;
 	}
 	state = BOUND;
@@ -2088,7 +2088,7 @@ Socket(AF_INET6, SOCK_STREAM, IPPROTO_TCP)
 
 	if(getaddrinfo(name, cp, &hint, &list) || !list) {
 		endSocket();
-		error(errBindingFailed, "Could not find service", errno);
+		error(errBindingFailed, (char *)"Could not find service", errno);
 		return;
 	}
 
@@ -2109,7 +2109,7 @@ Socket(AF_INET6, SOCK_STREAM, IPPROTO_TCP)
 	freeaddrinfo(first);
 	if(state != BOUND) {
 		endSocket();
-		error(errBindingFailed,"Could not bind socket",socket_errno);
+		error(errBindingFailed,(char *)"Could not bind socket",socket_errno);
 		return;
 	}
 
@@ -2117,7 +2117,7 @@ Socket(AF_INET6, SOCK_STREAM, IPPROTO_TCP)
 
 	if(listen(so, backlog)) {
 		endSocket();
-		error(errBindingFailed,"Could not listen on socket",socket_errno);
+		error(errBindingFailed,(char *)"Could not listen on socket",socket_errno);
 		return;
 	}
 }
@@ -2171,7 +2171,7 @@ Socket(AF_INET6, SOCK_STREAM, IPPROTO_TCP)
 
 	if(bind(so, (struct sockaddr *)&addr, sizeof(addr))) {
 		endSocket();
-		error(errBindingFailed,"Could not bind socket",socket_errno);
+		error(errBindingFailed,(char *)"Could not bind socket",socket_errno);
 		return;
 	}
 
@@ -2179,7 +2179,7 @@ Socket(AF_INET6, SOCK_STREAM, IPPROTO_TCP)
 
 	if(listen(so, backlog)) {
 		endSocket();
-		error(errBindingFailed,"Could not listen on socket",
+		error(errBindingFailed,(char *)"Could not listen on socket",
 			socket_errno);
 		return;
 	}
@@ -2204,7 +2204,7 @@ Socket(AF_INET6, SOCK_STREAM, IPPROTO_TCP)
 #endif
 	if(bind(so, (struct sockaddr *)&addr, sizeof(addr))) {
 		endSocket();
-		error(errBindingFailed,"Could not bind socket",socket_errno);
+		error(errBindingFailed,(char *)"Could not bind socket",socket_errno);
 		return;
 	}
 
@@ -2212,7 +2212,7 @@ Socket(AF_INET6, SOCK_STREAM, IPPROTO_TCP)
 
 	if(listen(so, backlog)) {
 		endSocket();
-		error(errBindingFailed,"Could not listen on socket",socket_errno);
+		error(errBindingFailed,(char *)"Could not listen on socket",socket_errno);
 		return;
 	}
 	state = BOUND;
@@ -2826,7 +2826,7 @@ void TCPStream::allocate(size_t size)
 	gbuf = new char[size];
 	pbuf = new char[size];
 	if(!pbuf || !gbuf) {
-		error(errResourceFailure, "Could not allocate socket stream buffers");
+		error(errResourceFailure, (char *)"Could not allocate socket stream buffers");
 		return;
 	}
 	bufsize = size;
@@ -2871,7 +2871,7 @@ int TCPStream::underflow()
 			rlen = ::read((int)so, (char *)&ch, 1);
 		else if(timeout && !Socket::isPending(pendingInput, timeout)) {
 			clear(ios::failbit | rdstate());
-			error(errTimeout,"Socket read timed out",socket_errno);
+			error(errTimeout,(char *)"Socket read timed out",socket_errno);
 			return EOF;
 		}
 		else
@@ -2879,7 +2879,7 @@ int TCPStream::underflow()
 		if(rlen < 1) {
 			if(rlen < 0) {
 				clear(ios::failbit | rdstate());
-				error(errInput,"Could not read from socket",socket_errno);
+				error(errInput,(char *)"Could not read from socket",socket_errno);
 			}
 			return EOF;
 		}
@@ -2897,7 +2897,7 @@ int TCPStream::underflow()
 		rlen = ::read((int)so, (char *)eback(), _IOLEN64 rlen);
 	else if(timeout && !Socket::isPending(pendingInput, timeout)) {
 		clear(ios::failbit | rdstate());
-		error(errTimeout,"Socket read timed out",socket_errno);
+		error(errTimeout,(char *)"Socket read timed out",socket_errno);
 		return EOF;
 	}
 	else
@@ -2905,9 +2905,9 @@ int TCPStream::underflow()
 	if(rlen < 1) {
 //		clear(ios::failbit | rdstate());
 		if(rlen < 0)
-						error(errNotConnected,"Connection error",socket_errno);
+						error(errNotConnected,(char *)"Connection error",socket_errno);
 		else {
-			error(errInput,"Could not read from socket",socket_errno);
+			error(errInput,(char *)"Could not read from socket",socket_errno);
 			clear(ios::failbit | rdstate());
 		}
 		return EOF;
@@ -2973,7 +2973,7 @@ int TCPStream::overflow(int c)
 		if(rlen < 1) {
 			if(rlen < 0) {
 				clear(ios::failbit | rdstate());
-				error(errOutput,"Could not write to socket",socket_errno);
+				error(errOutput,(char *)"Could not write to socket",socket_errno);
 			}
 			return EOF;
 		}
@@ -2993,7 +2993,7 @@ int TCPStream::overflow(int c)
 		if(rlen < 1) {
 			if(rlen < 0) {
 				clear(ios::failbit | rdstate());
-				error(errOutput,"Could not write to socket",socket_errno);
+				error(errOutput,(char *)"Could not write to socket",socket_errno);
 			}
 			return EOF;
 		}
