@@ -134,7 +134,7 @@ Socket(AF_INET, SOCK_DGRAM, IPPROTO_UDP)
 
 	if(bind(so, (struct sockaddr *)&addr, (socklen_t)sizeof(addr))) {
 		endSocket();
-		error(errBindingFailed,"Could not bind socket",socket_errno);
+		error(errBindingFailed,(char *)"Could not bind socket",socket_errno);
 		return;
 	}
 	state = BOUND;
@@ -166,7 +166,7 @@ Socket(AF_INET6, SOCK_DGRAM, IPPROTO_UDP)
 
 	if(bind(so, (struct sockaddr *)&addr, (socklen_t)sizeof(addr))) {
 		endSocket();
-		error(errBindingFailed,"Could not bind socket",socket_errno);
+		error(errBindingFailed,(char *)"Could not bind socket",socket_errno);
 		return;
 	}
 	state = BOUND;
